| noatak.dt | R Documentation |
This dataset provides Landsat time series data for 100 random sample locations within the Noatak National Preserve, USA. These data were extracted from Google Earth Engine using the lsat_export_ts() function.
data("noatak.dt")
A data frame with 99600 observations on the following 23 variables.
GEE index
CLOUD_COVERPercent cloud cover of scene
COLLECTION_NUMBERLandsat collection number
DATE_ACQUIREDAcquisition date in yyyy-mm-dd format
GEOMETRIC_RMSE_MODELRMSE of geometric residuals in meters
LANDSAT_PRODUCT_IDLandsat product identifier
LANDSAT_SCENE_IDLandsat scene identifier
PROCESSING_LEVELLandsat processing level
QA_PIXELCFMASK pixel quality attribute bitmask
QA_RADSATRadiometric saturation bitmask
SPACECRAFT_IDName of the spacecraft
SR_B1Band 1 surface reflectance
SR_B2Band 2 surface reflectance
SR_B3Band 3 surface reflectance
SR_B4Band 4 surface reflectance
SR_B5Band 5 surface reflectance
SR_B6Band 6 surface reflectance
SR_B7Band 7 surface reflectance
SUN_ELEVATIONSun elevation angle in degrees for the image center location at the image center acquisition time
chunk_idDownload chunk identifier
max_extentJRC maximum water extent flag
sample_idUser specificed sample location identifier
.geoSample location coordinates
Generated as example data for Berner et al. (2023)
Landsat data are provided by the United States Geological Survey
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.